@@ -131,9 +131,9 @@ public class SelectCellsByNumTranscripts
 			mapContainer = new SingleOrganismMapContainer(cellBarcodes);
 
         // gene/exon tags are sorted first, followed by cells
-        UMIIterator umiIterator = new UMIIterator(headerAndIterator, GENE_NAME_TAG, GENE_STRAND_TAG, GENE_FUNCTION_TAG,
+        UMIIterator umiIterator = new UMIIterator.UMIIteratorBuilder(headerAndIterator, GENE_NAME_TAG, GENE_STRAND_TAG, GENE_FUNCTION_TAG,
         		this.STRAND_STRATEGY, this.LOCUS_FUNCTION_LIST, this.FUNCTIONAL_STRATEGY, this.CELL_BARCODE_TAG, this.MOLECULAR_BARCODE_TAG,
-        		this.READ_MQ, false, cellBarcodes);
+        		this.READ_MQ).setCellBarcodes(cellBarcodes).build();
 
 
         String gene = null;
