@@ -28,7 +28,7 @@ import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 
-import org.apache.commons.lang.ArrayUtils;
+import org.apache.commons.lang3.ArrayUtils;
 import org.apache.commons.math3.stat.descriptive.moment.Mean;
 
 import htsjdk.samtools.AlignmentBlock;
@@ -102,7 +102,7 @@ public abstract class SNPBasePileUp implements Locatable,SNPIntervalRecordI {
 	public Double getAverageQuality () {
 		if (this.qualities.size()==0) return null;
 		Mean m = new Mean();
-		double [] q = this.qualities.stream().mapToDouble(x -> new Double(x)).toArray();
+		double [] q = this.qualities.stream().mapToDouble(x -> Double.valueOf(x)).toArray();
 		return m.evaluate(q);		
 	}
 
