@@ -38,13 +38,7 @@ import org.broadinstitute.dropseqrna.utils.MultiComparator;
 import org.broadinstitute.dropseqrna.utils.ProgressLoggingIterator;
 import org.broadinstitute.dropseqrna.utils.SamWriterSink;
 import org.broadinstitute.dropseqrna.utils.StringTagComparator;
-import org.broadinstitute.dropseqrna.utils.readiterators.ChromosomeFilteringIterator;
-import org.broadinstitute.dropseqrna.utils.readiterators.GeneFunctionIteratorWrapper;
-import org.broadinstitute.dropseqrna.utils.readiterators.MapQualityFilteredIterator;
-import org.broadinstitute.dropseqrna.utils.readiterators.MissingTagFilteringIterator;
-import org.broadinstitute.dropseqrna.utils.readiterators.SamHeaderAndIterator;
-import org.broadinstitute.dropseqrna.utils.readiterators.SamRecordSortingIteratorFactory;
-import org.broadinstitute.dropseqrna.utils.readiterators.StrandStrategy;
+import org.broadinstitute.dropseqrna.utils.readiterators.*;
 
 import htsjdk.samtools.SAMRecord;
 import htsjdk.samtools.SAMSequenceDictionary;
@@ -103,7 +97,7 @@ public class SNPUMIBasePileupIterator implements CloseableIterator<SNPUMIBasePil
 		final ProgressLogger logger = new ProgressLogger(LOG);
 
         // add a progress logger.
-        ProgressLoggingIterator loggingIterator = new ProgressLoggingIterator (headerAndIter.iterator, logger);
+        final ProgressLoggingIterator loggingIterator = new ProgressLoggingIterator (headerAndIter.iterator, logger);
 
         // filter out to contigs in the interval list.
         Set<String> contigsToFilter = snpIntervals.getIntervals().stream().map(x -> x.getContig()).collect(Collectors.toSet());
@@ -115,9 +109,10 @@ public class SNPUMIBasePileupIterator implements CloseableIterator<SNPUMIBasePil
         // Filter records before sorting, to reduce I/O
         final MissingTagFilteringIterator filteringIterator2 =
                 new MissingTagFilteringIterator(filteringIterator, geneTag, cellBarcodeTag, molecularBarcodeTag);
-        
+
+		final STARSoloChimericReadFilteringIterator chimericReadFilteringIterator = new STARSoloChimericReadFilteringIterator(filteringIterator2, molecularBarcodeTag);
      	// Filter/assign reads based on functional annotations
-     	GeneFunctionIteratorWrapper gfteratorWrapper = new GeneFunctionIteratorWrapper(filteringIterator2, geneTag, geneStrandTag, geneFunctionTag, assignReadsToAllGenes, strandStrategy, acceptedLociFunctions, functionStrategy);
+     	GeneFunctionIteratorWrapper gfteratorWrapper = new GeneFunctionIteratorWrapper(chimericReadFilteringIterator, geneTag, geneStrandTag, geneFunctionTag, assignReadsToAllGenes, strandStrategy, acceptedLociFunctions, functionStrategy);
      	
      	/**
      	 * In this section, data is sorted into the standard cell / gene / umi order and grouped so that all reads for a single UMI can be evaluated at once.
