@@ -28,6 +28,7 @@ import htsjdk.samtools.util.Log;
 import htsjdk.samtools.util.RuntimeIOException;
 import org.broadinstitute.barclay.argparser.Argument;
 import org.broadinstitute.barclay.argparser.CommandLineProgramProperties;
+import org.broadinstitute.dropseqrna.barnyard.digitalexpression.AbstractTripletDgeWriterClp;
 import org.broadinstitute.dropseqrna.barnyard.digitalexpression.DgeHeaderCodec;
 import org.broadinstitute.dropseqrna.barnyard.digitalexpression.DgeHeaderMerger;
 import org.broadinstitute.dropseqrna.cmdline.CustomCommandLineValidationHelper;
@@ -55,7 +56,7 @@ import java.util.stream.Collectors;
         programGroup = DropSeq.class
 )
 public class MergeDgeSparse
-        extends CommandLineProgram {
+        extends AbstractTripletDgeWriterClp {
 
     @Argument(shortName = "Y", doc="Input file containing list of data sets as for clustering workflow.\n" +
             "The file is expected to contain a 'datasets' list.  Each element of the list will contain:\n\n" +
@@ -276,6 +277,8 @@ public class MergeDgeSparse
             }
         }
 
+        maybeWriteNamesFiles(geneFiltererSorter.getSortedGeneNames(), cellBarcodes);
+
         LOG.info(numFilteredElements + " filtered by a gene filter.");
         return 0;
     }
@@ -474,8 +477,8 @@ public class MergeDgeSparse
             if (cellBarcodePath != null) {
                 final File cellBarcodeFile = new File(cellBarcodePath);
                 Set<String> unprefixedSelectedCells = loadSelectedCellsLists(Collections.singletonList(cellBarcodeFile));
-
                 dge.retainOnlyTheseCells(unprefixedSelectedCells);
+                LOG.info(String.format("After applying %s, %d cells remain.", cellBarcodeFile.getAbsolutePath(), dge.getNumCells()));
             }
 
             if (!prefix.isEmpty())
@@ -484,8 +487,12 @@ public class MergeDgeSparse
             if (cell_count > 0 && cell_count < dge.getNumCells())
                 dge.discardSmallestCells(cell_count);
 
-            if (selectedCells != null)
+            if (selectedCells != null) {
+                int numCellsBefore = dge.getNumCells();
                 dge.retainOnlyTheseCells(selectedCells);
+                LOG.info(String.format("%d cells removed after applying global CELL_BC_FILES.", numCellsBefore - dge.getNumCells()));
+            }
+
 
             if (MIN_GENES > 0) {
                 int numCells = dge.getNumCells();
