@@ -23,13 +23,13 @@
  */
 package org.broadinstitute.dropseqrna.readtrimming;
 
-import htsjdk.samtools.SAMRecord;
-import htsjdk.samtools.SAMTagUtil;
-import htsjdk.samtools.util.SequenceUtil;
-
 import java.util.ArrayList;
 import java.util.List;
 
+import htsjdk.samtools.SAMRecord;
+import htsjdk.samtools.SAMTag;
+import htsjdk.samtools.util.SequenceUtil;
+
 public class AdapterDescriptor {
     /**
      * RCed molecular barcode, RCed cell barcode.  Note that there is fixed sequence that follows the
@@ -63,7 +63,7 @@ public class AdapterDescriptor {
 
         TagAdapterElement(String tag, boolean reverseComplement) {
             this.stringTag = tag;
-            this.binaryTag = SAMTagUtil.getSingleton().makeBinaryTag(tag);
+            this.binaryTag = SAMTag.makeBinaryTag(tag);
             this.reverseComplement = reverseComplement;
         }
 
