@@ -1,11 +1,8 @@
 package org.broadinstitute.dropseqrna.utils.readiterators;
 
 import htsjdk.samtools.SAMRecord;
-import org.broadinstitute.dropseqrna.annotation.FunctionalData;
-import org.broadinstitute.dropseqrna.annotation.FunctionalDataProcessor;
-import org.broadinstitute.dropseqrna.barnyard.Utils;
+import org.broadinstitute.dropseqrna.annotation.functionaldata.FunctionalDataProcessorStrategy;
 import org.broadinstitute.dropseqrna.utils.CountChangingIteratorWrapper;
-import org.broadinstitute.dropseqrna.utils.PassFailTrackingIteratorI;
 
 import picard.annotation.LocusFunction;
 
@@ -14,22 +11,25 @@ import java.util.*;
 public class GeneFunctionIteratorWrapper extends
 		CountChangingIteratorWrapper<SAMRecord>  {
 
-	
-	private final GeneFunctionProcessor p;
+
+
+	private final GeneFunctionProcessor geneFunctionProcessor;
 	
 	public GeneFunctionIteratorWrapper(
 			final Iterator<SAMRecord> underlyingIterator, final String geneTag,
 			final String strandTag, final String functionTag,
 			final boolean assignReadsToAllGenes,
 			final StrandStrategy strandFilterStrategy,
-			final Collection<LocusFunction> acceptedLociFunctions) {
+			final Collection<LocusFunction> acceptedLociFunctions,
+			FunctionalDataProcessorStrategy functionStrategy) {
 		super(underlyingIterator);
-		p = new GeneFunctionProcessor(geneTag, strandTag, functionTag, assignReadsToAllGenes, strandFilterStrategy, acceptedLociFunctions);
+		geneFunctionProcessor = new GeneFunctionProcessor(geneTag, strandTag, functionTag, assignReadsToAllGenes,
+				strandFilterStrategy, acceptedLociFunctions, functionStrategy);
 	}
 
 	@Override
 	public void processRecord(final SAMRecord r) {
-		List<SAMRecord> result = p.processRead(r);
+		List<SAMRecord> result = geneFunctionProcessor.processRead(r);
 		if (result.size()==0)			
 			return;
 		
@@ -37,6 +37,9 @@ public class GeneFunctionIteratorWrapper extends
 			queueRecordForOutput(rr);
 	}
 
+	public GeneFunctionProcessor getGeneFunctionProcessor() {
+		return geneFunctionProcessor;
+	}
+
 
-	
 }
