@@ -25,6 +25,7 @@ package org.broadinstitute.dropseqrna.barnyard.digitalallelecounts.sampleassignm
 
 import htsjdk.samtools.util.Interval;
 import htsjdk.samtools.util.IntervalList;
+import htsjdk.samtools.util.Log;
 import htsjdk.samtools.util.PeekableIterator;
 import htsjdk.variant.variantcontext.VariantContext;
 import htsjdk.variant.variantcontext.VariantContextBuilder;
@@ -42,10 +43,11 @@ import org.testng.annotations.Test;
 
 import java.io.File;
 import java.io.IOException;
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.List;
-import java.util.Set;
+import java.text.DecimalFormat;
+import java.util.*;
+import java.util.function.Function;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
 
 public class AssignCellsToSamplesTest {
 
@@ -84,7 +86,7 @@ public class AssignCellsToSamplesTest {
 	private final File ONE_READ_TWO_SNPS_BAM = new File(rootDir+"/read_multiple_snps.bam");
 	private final File ONE_UMI_TWO_SNPS_BAM = new File(rootDir+"/umi_multiple_snps.bam");
 	private final File MULTI_SNP_TEST_VCF = new File (rootDir+"/multiple_snp_tests_small.vcf.gz");
-	
+
 	@Test
 	/**
 	 * The goal of this test is to see if the number of informative SNPs is one for a single read with two SNPs.
@@ -96,7 +98,7 @@ public class AssignCellsToSamplesTest {
 		assigner.INPUT_BAM=Collections.singletonList(this.ONE_READ_TWO_SNPS_BAM);
 		assigner.VCF=this.MULTI_SNP_TEST_VCF;
 		assigner.NUM_BARCODES=10; // more than enough
-		assigner.OUTPUT=File.createTempFile("AssignCellsToSamples", ".output");
+		assigner.OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".output");
 		int result = assigner.doWork();
 		Assert.assertEquals(result, 0);
 		
@@ -118,7 +120,7 @@ public class AssignCellsToSamplesTest {
 		assigner.INPUT_BAM=Collections.singletonList(this.ONE_UMI_TWO_SNPS_BAM);
 		assigner.VCF=this.MULTI_SNP_TEST_VCF;
 		assigner.NUM_BARCODES=10; // more than enough
-		assigner.OUTPUT=File.createTempFile("AssignCellsToSamples", ".output");
+		assigner.OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".output");
 		int result = assigner.doWork();
 		Assert.assertEquals(result, 0);
 		
@@ -145,19 +147,33 @@ public class AssignCellsToSamplesTest {
 		assigner.INPUT_BAM=Collections.singletonList(this.INPUT_BAM);
 		assigner.VCF=this.VCF_NON_CANONICAL;
 		assigner.NUM_BARCODES=10; // more than enough
-		assigner.OUTPUT=File.createTempFile("AssignCellsToSamples", ".output");
-		assigner.VCF_OUTPUT=File.createTempFile("AssignCellsToSamples", ".vcf");
-		assigner.BAM_OUTPUT=File.createTempFile("AssignCellsToSamples", ".informative.bam");
-		assigner.VERBOSE_OUTPUT=File.createTempFile("AssignCellsToSamples", ".verbose.gz");
-		assigner.VERBOSE_BEST_DONOR_OUTPUT=File.createTempFile("AssignCellsToSamples", ".best_verbose.gz");
+		assigner.OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".output");
+		assigner.VCF_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".vcf", "idx");
+		assigner.BAM_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".informative.bam");
+		assigner.VERBOSE_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".verbose.gz");
+		assigner.VERBOSE_BEST_DONOR_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".best_verbose.gz");
 		int result = assigner.doWork();
 		Assert.assertEquals(result, 0);
-		Assert.assertTrue(TestUtils.testFilesSame(EXPECTED_OUTPUT, assigner.OUTPUT));	
-		Assert.assertTrue(TestUtils.testFilesSame(EXPECTED_VERBOSE_OUTPUT, assigner.VERBOSE_OUTPUT));
+		Assert.assertTrue(TestUtils.testFilesSame(EXPECTED_OUTPUT, assigner.OUTPUT));
+		assertVerboseOutputSame(EXPECTED_VERBOSE_OUTPUT, assigner.VERBOSE_OUTPUT);
 		
 	}
-	
-	
+
+	private static final DecimalFormat Format12DecimalPlaces = new DecimalFormat("0.############");
+	private static Object format12DecimalPlaces(final String s) {
+		return Format12DecimalPlaces.format(Double.valueOf(s));
+	}
+	final Map<Integer, Function<String, Object>> VerboseOutputTransformerMap = new HashMap<>();
+	{
+		VerboseOutputTransformerMap.put(13, AssignCellsToSamplesTest::format12DecimalPlaces);
+		VerboseOutputTransformerMap.put(14, AssignCellsToSamplesTest::format12DecimalPlaces);
+		VerboseOutputTransformerMap.put(15, AssignCellsToSamplesTest::format12DecimalPlaces);
+		VerboseOutputTransformerMap.put(16, AssignCellsToSamplesTest::format12DecimalPlaces);
+	}
+	private void assertVerboseOutputSame(final File expected, final File actual) {
+		Assert.assertTrue(TestUtils.testTabularFilesSame(expected, actual, VerboseOutputTransformerMap));
+	}
+
 	@Test
 	public void testEndToEnd() throws IOException {
 		AssignCellsToSamples assigner = new AssignCellsToSamples();
@@ -165,18 +181,19 @@ public class AssignCellsToSamplesTest {
 		assigner.INPUT_BAM=Collections.singletonList(this.INPUT_BAM);
 		assigner.VCF=this.VCFC;
 		assigner.NUM_BARCODES=10; // more than enough
-		assigner.OUTPUT=File.createTempFile("AssignCellsToSamples", ".output");
-		assigner.VCF_OUTPUT=File.createTempFile("AssignCellsToSamples", ".vcf");
-		assigner.BAM_OUTPUT=File.createTempFile("AssignCellsToSamples", ".informative.bam");
-		assigner.VERBOSE_OUTPUT=File.createTempFile("AssignCellsToSamples", ".verbose.gz");
-		assigner.VERBOSE_BEST_DONOR_OUTPUT=File.createTempFile("AssignCellsToSamples", ".best_verbose.gz");
+		assigner.OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".output");
+		assigner.VCF_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".vcf", "idx");
+		assigner.BAM_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".informative.bam");
+		assigner.VERBOSE_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".verbose.gz");
+		assigner.VERBOSE_BEST_DONOR_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".best_verbose.gz");
 		
 		int result = assigner.doWork();
 		Assert.assertEquals(result, 0);
 		Assert.assertTrue(TestUtils.testFilesSame(EXPECTED_OUTPUT, assigner.OUTPUT));	
-		Assert.assertTrue(TestUtils.testFilesSame(EXPECTED_VERBOSE_OUTPUT, assigner.VERBOSE_OUTPUT));
+		assertVerboseOutputSame(EXPECTED_VERBOSE_OUTPUT, assigner.VERBOSE_OUTPUT);
 		
 	}
+
 	
 	/**
 	 * Uses a sample list that has entries not in the VCF.
@@ -190,11 +207,11 @@ public class AssignCellsToSamplesTest {
 		assigner.VCF=this.VCFC;
 		assigner.SAMPLE_FILE=WRONG_SAMPLE_LIST;
 		assigner.NUM_BARCODES=10; // more than enough
-		assigner.OUTPUT=File.createTempFile("AssignCellsToSamples", ".output");
-		assigner.VCF_OUTPUT=File.createTempFile("AssignCellsToSamples", ".vcf");
-		assigner.BAM_OUTPUT=File.createTempFile("AssignCellsToSamples", ".informative.bam");
-		assigner.VERBOSE_OUTPUT=File.createTempFile("AssignCellsToSamples", ".verbose.gz");
-		assigner.VERBOSE_BEST_DONOR_OUTPUT=File.createTempFile("AssignCellsToSamples", ".best_verbose.gz");
+		assigner.OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".output");
+		assigner.VCF_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".vcf", "idx");
+		assigner.BAM_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".informative.bam");
+		assigner.VERBOSE_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".verbose.gz");
+		assigner.VERBOSE_BEST_DONOR_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".best_verbose.gz");
 		int result = assigner.doWork();
 		Assert.assertEquals(result, 0);		
 	}	
@@ -211,11 +228,11 @@ public class AssignCellsToSamplesTest {
 		assigner.VCF=this.VCFC;
 		assigner.SAMPLE_FILE=DUPLICATE_SAMPLE_LIST;
 		assigner.NUM_BARCODES=10; // more than enough
-		assigner.OUTPUT=File.createTempFile("AssignCellsToSamples", ".output");
-		assigner.VCF_OUTPUT=File.createTempFile("AssignCellsToSamples", ".vcf");
-		assigner.BAM_OUTPUT=File.createTempFile("AssignCellsToSamples", ".informative.bam");
-		assigner.VERBOSE_OUTPUT=File.createTempFile("AssignCellsToSamples", ".verbose.gz");
-		assigner.VERBOSE_BEST_DONOR_OUTPUT=File.createTempFile("AssignCellsToSamples", ".best_verbose.gz");
+		assigner.OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".output");
+		assigner.VCF_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".vcf", "idx");
+		assigner.BAM_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".informative.bam");
+		assigner.VERBOSE_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".verbose.gz");
+		assigner.VERBOSE_BEST_DONOR_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".best_verbose.gz");
 		int result = assigner.doWork();
 		Assert.assertEquals(result, 0);		
 	}
@@ -233,11 +250,11 @@ public class AssignCellsToSamplesTest {
 		assigner.VCF=this.VCF_FAIL_FAST;
 		assigner.TRANSCRIBED_SNP_FAIL_FAST_THRESHOLD=5;		
 		assigner.NUM_BARCODES=10; // more than enough
-		assigner.OUTPUT=File.createTempFile("AssignCellsToSamples", ".output");
-		assigner.VCF_OUTPUT=File.createTempFile("AssignCellsToSamples", ".vcf");
-		assigner.BAM_OUTPUT=File.createTempFile("AssignCellsToSamples", ".informative.bam");
-		assigner.VERBOSE_OUTPUT=File.createTempFile("AssignCellsToSamples", ".verbose.gz");
-		assigner.VERBOSE_BEST_DONOR_OUTPUT=File.createTempFile("AssignCellsToSamples", ".best_verbose.gz");
+		assigner.OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".output");
+		assigner.VCF_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".vcf", "idx");
+		assigner.BAM_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".informative.bam");
+		assigner.VERBOSE_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".verbose.gz");
+		assigner.VERBOSE_BEST_DONOR_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".best_verbose.gz");
 		int result = assigner.doWork();
 		Assert.assertEquals(result, 0);		
 	}
@@ -250,10 +267,10 @@ public class AssignCellsToSamplesTest {
 		assigner.INPUT_BAM=Collections.singletonList(this.INPUT_BAM);
 		assigner.VCF=this.VCFC;
 		assigner.NUM_BARCODES=10; // more than enough
-		assigner.OUTPUT=File.createTempFile("AssignCellsToSamples", ".output");
-		assigner.BAM_OUTPUT=File.createTempFile("AssignCellsToSamples", ".informative.bam");
-		assigner.VERBOSE_OUTPUT=File.createTempFile("AssignCellsToSamples", ".verbose.gz");
-		assigner.VERBOSE_BEST_DONOR_OUTPUT=File.createTempFile("AssignCellsToSamples", ".best_verbose.gz");
+		assigner.OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".output");
+		assigner.BAM_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".informative.bam");
+		assigner.VERBOSE_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".verbose.gz");
+		assigner.VERBOSE_BEST_DONOR_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".best_verbose.gz");
 		assigner.ANSWER_KEY_FILE=ANSWER_KEY;
 		
 		int result = assigner.doWork();
@@ -271,14 +288,14 @@ public class AssignCellsToSamplesTest {
 		assigner.VCF=this.VCFC;
 		assigner.NUM_BARCODES=10; // more than enough
 		assigner.MAX_ERROR_RATE=0.1; // -1 per UMI when the donor is homozygous with the wrong allele is the "max" score.
-		assigner.OUTPUT=File.createTempFile("AssignCellsToSamples", ".output");
-		assigner.BAM_OUTPUT=File.createTempFile("AssignCellsToSamples", ".informative.bam");
-		assigner.VERBOSE_OUTPUT=File.createTempFile("AssignCellsToSamples", ".verbose.gz");
-		assigner.VERBOSE_BEST_DONOR_OUTPUT=File.createTempFile("AssignCellsToSamples", ".best_verbose.gz");
+		assigner.OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".output");
+		assigner.BAM_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".informative.bam");
+		assigner.VERBOSE_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".verbose.gz");
+		assigner.VERBOSE_BEST_DONOR_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".best_verbose.gz");
 		int result = assigner.doWork();
 		Assert.assertEquals(result, 0);
-		Assert.assertTrue(TestUtils.testFilesSame(EXPECTED_MAXLIKE_OUTPUT, assigner.OUTPUT)); 
-		Assert.assertTrue(TestUtils.testFilesSame(EXPECTED_MAXLIKE_VERBOSE_OUTPUT, assigner.VERBOSE_OUTPUT)); 
+		Assert.assertTrue(TestUtils.testFilesSame(EXPECTED_MAXLIKE_OUTPUT, assigner.OUTPUT));
+		assertVerboseOutputSame(EXPECTED_MAXLIKE_VERBOSE_OUTPUT, assigner.VERBOSE_OUTPUT);
 	}
 
 	@Test (enabled=true)
@@ -289,17 +306,17 @@ public class AssignCellsToSamplesTest {
 		assigner.INPUT_BAM=Collections.singletonList(this.INPUT_BAM);
 		assigner.VCF=this.VCFC;
 		assigner.NUM_BARCODES=10; // more than enough
-		assigner.OUTPUT=File.createTempFile("AssignCellsToSamples", ".output");
-		assigner.BAM_OUTPUT=File.createTempFile("AssignCellsToSamples", ".informative.bam");
-		assigner.VERBOSE_OUTPUT=File.createTempFile("AssignCellsToSamples", ".verbose.gz");
-		assigner.VERBOSE_BEST_DONOR_OUTPUT=File.createTempFile("AssignCellsToSamples", ".best_verbose.gz");
+		assigner.OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".output");
+		assigner.BAM_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".informative.bam");
+		assigner.VERBOSE_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".verbose.gz");
+		assigner.VERBOSE_BEST_DONOR_OUTPUT=TestUtils.getTempReportFile("AssignCellsToSamples.", ".best_verbose.gz");
 		assigner.CELL_CONTAMINATION_ESTIMATE_FILE=CONTAMINATION_FILE;
 		assigner.ALLELE_FREQUENCY_ESTIMATE_FILE=MAF_ESIMATE_FILE;
 		
 		int result = assigner.doWork();
 		Assert.assertEquals(result, 0);		
-		Assert.assertTrue(TestUtils.testFilesSame(EXPECTED_CONTAM_OUTPUT, assigner.OUTPUT));	
-		Assert.assertTrue(TestUtils.testFilesSame(EXPECTED_CONTAM_VERBOSE_OUTPUT, assigner.VERBOSE_OUTPUT));
+		Assert.assertTrue(TestUtils.testFilesSame(EXPECTED_CONTAM_OUTPUT, assigner.OUTPUT));
+		assertVerboseOutputSame(EXPECTED_CONTAM_VERBOSE_OUTPUT, assigner.VERBOSE_OUTPUT);
 		
 	}
 	
