@@ -7,7 +7,7 @@ import java.util.Collections;
 import org.broadinstitute.dropseqrna.utils.TestUtils;
 import org.testng.annotations.Test;
 
-import junit.framework.Assert;
+import org.testng.Assert;
 
 public class GatherReadQualityMetricsTest {
 
