@@ -38,7 +38,7 @@ import java.util.*;
 public class DownsampleBamByTagTest {
 
     private static final File TESTDATA_DIR = new File("testdata/org/broadinstitute/dropseq/utils");
-    private static final File ALIGNED_UNPAIRED_BAM = new File(TESTDATA_DIR, "N701_small.bam");
+    private static final File ALIGNED_UNPAIRED_BAM = new File(TESTDATA_DIR, "N701_very_small.sam");
     private static final String TAG = "XC";
     private static final File ALIGNED_PAIRED_BAM = new File(TESTDATA_DIR, "d0GRIA3_A.multi_organism.MOUSE.census.paired.bam");
 
