@@ -27,7 +27,7 @@ import htsjdk.samtools.metrics.MetricsFile;
 import htsjdk.samtools.util.IOUtil;
 import htsjdk.samtools.util.StringUtil;
 import org.broadinstitute.dropseqrna.utils.io.ErrorCheckingPrintStream;
-import org.junit.Assert;
+import org.testng.Assert;
 import org.testng.Reporter;
 import org.testng.annotations.DataProvider;
 import org.testng.annotations.Test;
@@ -45,7 +45,7 @@ import java.util.stream.Collectors;
 
 public class SplitBamByCellTest {
 
-    public static final File TEST_BAM = new File("testdata/org/broadinstitute/dropseq/barnyard/DgeStrandFuncTest/DgeStrandFuncTest.bam");
+    public static final File TEST_BAM = new File("testdata/org/broadinstitute/dropseq/utils/SplitBamByCell.aligned.bam");
     private static final File EXPECTED_REPORT = new File ("testdata/org/broadinstitute/dropseq/utils/SplitBamByCell.report");
     private static final File EXPECTED_MANIFEST = new File ("testdata/org/broadinstitute/dropseq/utils/SplitBamByCell.split_bam_manifest");
     private static final File QUERYNAME_SORTED_BAM = new File("testdata/org/broadinstitute/dropseq/metrics/compute_umi_sharing.unmapped.sam");
@@ -65,6 +65,7 @@ public class SplitBamByCellTest {
         bamSplitter.OUTPUT=TestUtils.getTempReportFile("SplitBamByCell.", "." + bamSplitter.OUTPUT_SLUG + ".bam");
         bamSplitter.OUTPUT_LIST=outputBAMList;
         bamSplitter.NUM_OUTPUTS = 3;
+        TestUtils.markBamsDeleteOnExit(bamSplitter.OUTPUT, bamSplitter.OUTPUT_SLUG, bamSplitter.NUM_OUTPUTS);
         bamSplitter.DELETE_INPUTS = false;
         bamSplitter.OVERWRITE_EXISTING = true;
         bamSplitter.REPORT = report;
@@ -134,6 +135,7 @@ public class SplitBamByCellTest {
     @Test
     public void testTargetSplitSizeAndOverwrite() throws IOException {
         SplitBamByCell bamSplitter;
+        final int expectedBams = 3;
 
         File inputBam = TestUtils.getTempReportFile("SplitBamByCell.", ".bam");
         File outputBAMList = TestUtils.getTempReportFile("SplitBamByCell.", ".list");
@@ -144,14 +146,15 @@ public class SplitBamByCellTest {
         bamSplitter = new SplitBamByCell();
         bamSplitter.INPUT = Collections.singletonList(inputBam);
         bamSplitter.OUTPUT = TestUtils.getTempReportFile("SplitBamByCell.", "." + bamSplitter.OUTPUT_SLUG + ".bam");
+        TestUtils.markBamsDeleteOnExit(bamSplitter.OUTPUT, bamSplitter.OUTPUT_SLUG, expectedBams);
         bamSplitter.OUTPUT_LIST = outputBAMList;
         bamSplitter.REPORT = reportFile;
-        bamSplitter.TARGET_BAM_SIZE = "1.5M";
+        bamSplitter.TARGET_BAM_SIZE = "150K";
         bamSplitter.DELETE_INPUTS = false;
         Assert.assertEquals(bamSplitter.doWork(), 0);
 
         List<File> splitBAMFileList = FileListParsingUtils.readFileList(outputBAMList);
-        Assert.assertEquals(splitBAMFileList.size(), 3);
+        Assert.assertEquals(splitBAMFileList.size(), expectedBams);
         for (File f : splitBAMFileList) {
             f.deleteOnExit();
         }
@@ -179,7 +182,6 @@ public class SplitBamByCellTest {
         bamSplitter.OUTPUT = previousOutputTemplate;
         bamSplitter.OUTPUT_LIST = outputBAMList;
         bamSplitter.REPORT = reportFile;
-        bamSplitter.DELETE_INPUTS = false;
         bamSplitter.TARGET_BAM_SIZE = "2M";
         bamSplitter.OVERWRITE_EXISTING = true;
         bamSplitter.DELETE_INPUTS = true;
@@ -332,11 +334,13 @@ public class SplitBamByCellTest {
         final File mergedOutputBAM = TestUtils.getTempReportFile("SplitBamByCell.merged.", ".sam");
         mergedOutputBAM.deleteOnExit();
 
+        final int numOutputs = 3;
         bamSplitter.INPUT = Collections.singletonList(TEST_BAM);
         bamSplitter.OUTPUT =
                 TestUtils.getTempReportFile("SplitBamByCell.", "." + bamSplitter.OUTPUT_SLUG + ".bam");
+        TestUtils.markBamsDeleteOnExit(bamSplitter.OUTPUT, bamSplitter.OUTPUT_SLUG, numOutputs);
         bamSplitter.OUTPUT_LIST = TestUtils.getTempReportFile("SplitBamByCell.", ".list");
-        bamSplitter.NUM_OUTPUTS = 3;
+        bamSplitter.NUM_OUTPUTS = numOutputs;
         bamSplitter.DELETE_INPUTS = false;
         bamSplitter.OVERWRITE_EXISTING = true;
         bamSplitter.REPORT = TestUtils.getTempReportFile("SplitBamByCell.", ".report");
@@ -356,8 +360,8 @@ public class SplitBamByCellTest {
     public Object[][] testSplitGeneThresholdFailDataProvider() {
         return new Object[][] {
                 {-1d},
-                {0.9},
-                {60000d},
+                {0.95},
+                {5500d},
         };
     }
 
@@ -420,8 +424,8 @@ public class SplitBamByCellTest {
         // split BAMs + bam_list and report
         Assert.assertEquals(expectedExtensions.size(), outputFiles.size());
         for (final String expectedExtension: expectedExtensions) {
-            Assert.assertTrue("Test presence of " + expectedExtension,
-                    outputFileNames.contains(symlinkBasename + expectedExtension));
+            Assert.assertTrue(outputFileNames.contains(symlinkBasename + expectedExtension), "Test presence of " + expectedExtension
+                    );
         }
     }
 
