@@ -36,7 +36,7 @@ import java.util.Map;
 import java.util.Set;
 import java.util.stream.Collectors;
 
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.RandomStringUtils;
 import org.broadinstitute.dropseqrna.metrics.UmiSharingMetrics;
 import org.broadinstitute.dropseqrna.metrics.umisharing.ParentEditDistanceMatcher;
@@ -50,7 +50,7 @@ import htsjdk.samtools.SAMRecordIterator;
 import htsjdk.samtools.SamReader;
 import htsjdk.samtools.SamReaderFactory;
 import htsjdk.samtools.util.IOUtil;
-import junit.framework.Assert;
+import org.testng.Assert;
 import picard.util.TabbedInputParser;
 
 public class MapBarcodesByEditDistanceTest {
